@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class EnumerationConfig(AppConfig):
-    name = 'enumeration'
+    name = "enumeration"
